/*
 * HiPWiNS - High Performance Wireless Network Simulator
 * File: core/EventParameterTuple.java
 * 
 * Copyright 2010 Institute of Computer Science 4, University of Bonn, Germany
 * 
 * Licensed under the Apache License, Version 2.0 (the "License");
 * you may not use this file except in compliance with the License.
 * You may obtain a copy of the License at
 *
 *      http://www.apache.org/licenses/LICENSE-2.0
 *
 * Unless required by applicable law or agreed to in writing, software
 * distributed under the License is distributed on an "AS IS" BASIS,
 * WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND, either express or implied.
 * See the License for the specific language governing permissions and
 * limitations under the License.
 */

package core;

/**
 * Generic class for event parameter tuples.
 * 
 * @author Patrick Peschlow
 * @author Andreas Voss
 * 
 * @version 1.0
 */
public class EventParameterTuple {
	/**
	 * First parameter.
	 */
	Object param1_ = null;

	/**
	 * Second parameter.
	 */
	Object param2_ = null;

	/**
	 * Third parameter.
	 */
	Object param3_ = null;

	/**
	 * Fourth parameter.
	 */
	Object param4_ = null;

	/**
	 * Another tuple to be used if four parameters are not enough.
	 */
	EventParameterTuple nextTuple_ = null;

	/**
	 * Constructor. Uses a single parameter.
	 * 
	 * @param param1
	 *            the parameter.
	 */
	public EventParameterTuple(Object param1) {
		param1_ = param1;
	}

	/**
	 * Constructor. Uses two parameters.
	 * 
	 * @param param1
	 *            the first parameter.
	 * @param param2
	 *            the second parameter.
	 */
	public EventParameterTuple(Object param1, Object param2) {
		param1_ = param1;
		param2_ = param2;
	}

	/**
	 * Constructor. Uses three parameters.
	 * 
	 * @param param1
	 *            the first parameter.
	 * @param param2
	 *            the second parameter.
	 * @param param3
	 *            the three parameter.
	 */
	public EventParameterTuple(Object param1, Object param2, Object param3) {
		param1_ = param1;
		param2_ = param2;
		param3_ = param3;
	}

	/**
	 * Constructor. Uses four parameters.
	 * 
	 * @param param1
	 *            the first parameter.
	 * @param param2
	 *            the second parameter.
	 * @param param3
	 *            the three parameter.
	 * @param param4
	 *            the fourth parameter.
	 */
	public EventParameterTuple(Object param1, Object param2, Object param3,
			Object param4) {
		param1_ = param1;
		param2_ = param2;
		param3_ = param3;
		param4_ = param4;
	}

	/**
	 * Constructor. Uses more than four parameters.
	 * 
	 * @param param1
	 *            the first parameter.
	 * @param param2
	 *            the second parameter.
	 * @param param3
	 *            the three parameter.
	 * @param param4
	 *            the fourth parameter.
	 * @param nextTuple
	 *            the tuple that holds all further parameters.
	 */
	public EventParameterTuple(Object param1, Object param2, Object param3,
			Object param4, EventParameterTuple nextTuple) {
		param1_ = param1;
		param2_ = param2;
		param3_ = param3;
		param4_ = param4;
		nextTuple_ = nextTuple;
	}

	/**
	 * Provides the first parameter.
	 * 
	 * @return the first parameter.
	 */
	public Object getParam1() {
		return param1_;
	}

	/**
	 * Provides the second parameter.
	 * 
	 * @return the second parameter.
	 */
	public Object getParam2() {
		return param2_;
	}

	/**
	 * Provides the third parameter.
	 * 
	 * @return the third parameter.
	 */
	public Object getParam3() {
		return param3_;
	}

	/**
	 * Provides the fourth parameter.
	 * 
	 * @return the fourth parameter.
	 */
	public Object getParam4() {
		return param4_;
	}

	/**
	 * Provides the next parameter tuple.
	 * 
	 * @return the next parameter tuple.
	 */
	public EventParameterTuple getNextTuple() {
		return nextTuple_;
	}

	/**
	 * @see java.lang.Object#toString()
	 */
	@Override
	public String toString() {
		StringBuilder s = new StringBuilder();
		if (param1_ != null) {
			s.append(param1_.toString());
		}
		if (param2_ != null) {
			s.append(",").append(param2_.toString());
		}
		if (param3_ != null) {
			s.append(",").append(param3_.toString());
		}
		if (param4_ != null) {
			s.append(",").append(param4_.toString());
		}
		if (nextTuple_ != null) {
			s.append(",").append(nextTuple_.toString());
		}
		return s.toString();
	}
}
