/*
 * HiPWiNS - High Performance Wireless Network Simulator
 * File: distribution/BarrierPacket.java
 * 
 * Copyright 2010 Institute of Computer Science 4, University of Bonn, Germany
 * 
 * Licensed under the Apache License, Version 2.0 (the "License");
 * you may not use this file except in compliance with the License.
 * You may obtain a copy of the License at
 *
 *      http://www.apache.org/licenses/LICENSE-2.0
 *
 * Unless required by applicable law or agreed to in writing, software
 * distributed under the License is distributed on an "AS IS" BASIS,
 * WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND, either express or implied.
 * See the License for the specific language governing permissions and
 * limitations under the License.
 */

package core.distribution;

import java.io.Serializable;
import java.util.List;

import core.Event;

/**
 * Bundles information to be sent between clients and server during a barrier.
 * 
 * @author Patrick Peschlow
 * 
 * @version 1.0
 */
public class BarrierPacket implements Serializable {
	/**
	 * Default ID.
	 */
	private static final long serialVersionUID = 1L;

	/**
	 * Safe time bound.
	 */
	private final long safeTimeBound_;

	/**
	 * Events.
	 */
	private final List<Event> events_;

	/**
	 * Constructor.
	 * 
	 * @param safeTimeBound
	 *            the safe time bound.
	 * @param events
	 *            the list of events to be sent.
	 */
	public BarrierPacket(long safeTimeBound, List<Event> events) {
		safeTimeBound_ = safeTimeBound;
		events_ = events;
	}

	/**
	 * Provides the safe time bound.
	 * 
	 * @return the safe time bound.
	 */
	public long getSafeTimeBound() {
		return safeTimeBound_;
	}

	/**
	 * Provides the list of events.
	 * 
	 * @return the list of events.
	 */
	public List<Event> getEvents() {
		return events_;
	}
}
