/*
 * HiPWiNS - High Performance Wireless Network Simulator
 * File: core/scheduler/EventQueue.java
 * 
 * Copyright 2010 Institute of Computer Science 4, University of Bonn, Germany
 * 
 * Licensed under the Apache License, Version 2.0 (the "License");
 * you may not use this file except in compliance with the License.
 * You may obtain a copy of the License at
 *
 *      http://www.apache.org/licenses/LICENSE-2.0
 *
 * Unless required by applicable law or agreed to in writing, software
 * distributed under the License is distributed on an "AS IS" BASIS,
 * WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND, either express or implied.
 * See the License for the specific language governing permissions and
 * limitations under the License.
 */

package core.scheduler;

import core.Event;

/**
 * Abstract base class for event queue implementations.
 * 
 * @author Patrick Peschlow
 * 
 * @version 1.0
 */
public interface EventQueue {
	/**
	 * Returns the size of event queue.
	 * 
	 * @return the number of events in event queue.
	 */
	public int size();

	/**
	 * Whether the event queue is empty.
	 * 
	 * @return whether the event queue is empty.
	 */
	public boolean isEmpty();

	/**
	 * Inserts an event into event queue.
	 * 
	 * @param event
	 *            the event to insert.
	 */
	public void insert(Event event);

	/**
	 * Removes and returns the first event in queue.
	 * 
	 * @return the first event (removed) from queue.
	 */
	public Event removeFirst();

	/**
	 * Peeks at the first event in queue.
	 * 
	 * @return the first event (still) in queue.
	 */
	public Event peekFirst();
}