/*
 * HiPWiNS - High Performance Wireless Network Simulator
 * File: core/sync/AbstractSimController.java
 * 
 * Copyright 2010 Institute of Computer Science 4, University of Bonn, Germany
 * 
 * Licensed under the Apache License, Version 2.0 (the "License");
 * you may not use this file except in compliance with the License.
 * You may obtain a copy of the License at
 *
 *      http://www.apache.org/licenses/LICENSE-2.0
 *
 * Unless required by applicable law or agreed to in writing, software
 * distributed under the License is distributed on an "AS IS" BASIS,
 * WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND, either express or implied.
 * See the License for the specific language governing permissions and
 * limitations under the License.
 */

package core.sync;

import core.util.CustomLogger;

/**
 * An abstract base class for simulation controllers.
 * 
 * @author Patrick Peschlow
 * 
 * @version 1.0
 */
public abstract class AbstractSimController {
	/**
	 * Called to start the simulation.
	 */
	public void startSim() {
		Thread.currentThread().setName("SimController");

		if (CustomLogger.isInfoEnabled()) {
			CustomLogger.info("AbstractSimController: Starting simulation.");
		}

		final double startWallclockTime_ = System.currentTimeMillis();

		prepareSim();

		runSim();

		finishSim();

		final double endWallclockTime = System.currentTimeMillis();
		final double runTime = endWallclockTime - startWallclockTime_;

		if (CustomLogger.isInfoEnabled()) {
			CustomLogger
					.info("AbstractSimController: Simulation stopped. Run time: "
							+ runTime / 1000.0 + " seconds.");
		}

		// And here the application just returns and exits.
	}

	/**
	 * Initial preparations before running the simulation.
	 */
	protected abstract void prepareSim();

	/**
	 * Runs the simulation.
	 */
	protected abstract void runSim();

	/**
	 * Final round-up after finishing the simulation.
	 */
	protected abstract void finishSim();
}
