/*
 * HiPWiNS - High Performance Wireless Network Simulator
 * File: core/sync/DistributedLp.java
 * 
 * Copyright 2010 Institute of Computer Science 4, University of Bonn, Germany
 * 
 * Licensed under the Apache License, Version 2.0 (the "License");
 * you may not use this file except in compliance with the License.
 * You may obtain a copy of the License at
 *
 *      http://www.apache.org/licenses/LICENSE-2.0
 *
 * Unless required by applicable law or agreed to in writing, software
 * distributed under the License is distributed on an "AS IS" BASIS,
 * WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND, either express or implied.
 * See the License for the specific language governing permissions and
 * limitations under the License.
 */

package core.sync;

import modules.wireless.partition.DistributedPartition;
import modules.wireless.partition.Partition;
import core.Config;
import core.Event;
import core.scheduler.EventScheduler;

/**
 * An LP for use with DistributedSimController.
 * 
 * @author Patrick Peschlow
 * @author Martin Geuer
 * 
 * @version 1.0
 */
public class DistributedLp extends ParallelLp {
	/**
	 * Constructor.
	 * 
	 * @param lpId
	 *            the LP ID.
	 * @param scheduler
	 *            the scheduler.
	 * @param simCtrl
	 *            the SimController.
	 */
	DistributedLp(int lpId, EventScheduler scheduler,
			LpBasedSimController simCtrl) {
		super(lpId, scheduler, simCtrl);
	}

	/**
	 * @see core.sync.ParallelLp#createNewEvent(long, int, int, java.lang.Enum,
	 *      java.lang.Object, int, long)
	 */
	@SuppressWarnings("rawtypes")
	@Override
	public void createNewEvent(long execTime, int dstModuleId, int srcModuleId,
			Enum eventId, Object parameter, int priority, long schedTime) {
		// Only schedule events smaller or equal to the simulation end time.
		if (execTime > Config.getEndTime()) {
			return;
		}

		final Event event = new Event(execTime, schedTime, dstModuleId,
				srcModuleId, eventId, parameter, priority);

		if (dstModuleId == DistributedPartition.DIST_PARTITION_BROADCAST) {
			assert eventId == Partition.Events.LPPROPAGATION;
			minSendExecTime_ = Math.min(minSendExecTime_, event.getExecTime());
			simCtrl_.sendEvent(event, lpId_);
		} else {
			assert moduleMap_.containsKey(dstModuleId);
			receiveEvent(event);
		}
	}
}
