/*
 * HiPWiNS - High Performance Wireless Network Simulator
 * File: core/sync/Lp.java
 * 
 * Copyright 2010 Institute of Computer Science 4, University of Bonn, Germany
 * 
 * Licensed under the Apache License, Version 2.0 (the "License");
 * you may not use this file except in compliance with the License.
 * You may obtain a copy of the License at
 *
 *      http://www.apache.org/licenses/LICENSE-2.0
 *
 * Unless required by applicable law or agreed to in writing, software
 * distributed under the License is distributed on an "AS IS" BASIS,
 * WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND, either express or implied.
 * See the License for the specific language governing permissions and
 * limitations under the License.
 */

package core.sync;

import gnu.trove.TIntObjectHashMap;
import core.BaseModule;

/**
 * Interface for LPs.
 * 
 * @author Patrick Peschlow
 * 
 * @version 1.0
 */
public interface Lp {
	/**
	 * Sets the map containing the modules of this LP.
	 * 
	 * @param moduleMap
	 *            the module map.
	 */
	public void setModuleMap(TIntObjectHashMap<BaseModule> moduleMap);

	/**
	 * Creates a new event. Since the event may be destined to a different LP,
	 * it is forwarded if necessary.
	 * 
	 * @param execTime
	 *            the execution time of the event.
	 * @param dstModuleId
	 *            the destination module ID of the event.
	 * @param srcModuleId
	 *            the source module ID of the event.
	 * @param eventId
	 *            the ID of the event.
	 * @param parameter
	 *            the parameter of the event.
	 * @param priority
	 *            the priority value of the event.
	 */
	@SuppressWarnings("rawtypes")
	public void createNewEvent(long execTime, int dstModuleId, int srcModuleId,
			Enum eventId, Object parameter, int priority);

	/**
	 * Creates a new event. Since the event may be destined to a different LP,
	 * it is forwarded if necessary.
	 * 
	 * @param execTime
	 *            the execution time of the event.
	 * @param dstModuleId
	 *            the destination module ID of the event.
	 * @param srcModuleId
	 *            the source module ID of the event.
	 * @param eventId
	 *            the ID of the event.
	 * @param parameter
	 *            the parameter of the event.
	 * @param priority
	 *            the priority value of the event.
	 * @param schedTime
	 *            the scheduling time of the event.
	 */
	@SuppressWarnings("rawtypes")
	public void createNewEvent(long execTime, int dstModuleId, int srcModuleId,
			Enum eventId, Object parameter, int priority, long schedTime);

	/**
	 * Writes information to the event trace file for this LP.
	 * 
	 * @param time
	 *            the time stamp of the event.
	 * @param nodeId
	 *            the ID of the node handling the event.
	 * @param eventId
	 *            the ID of the event.
	 * @param eventParam
	 *            the parameter of the event.
	 */
	@SuppressWarnings("rawtypes")
	public void trace(long time, int nodeId, Enum eventId, Object eventParam);

	/**
	 * Provides (and increments) the next priority value for an event created at
	 * this LP.
	 * 
	 * @return the next priority value.
	 */
	public int getAndIncrementPriority();
}
