/*
 * HiPWiNS - High Performance Wireless Network Simulator
 * File: core/sync/LpBasedSimController.java
 * 
 * Copyright 2010 Institute of Computer Science 4, University of Bonn, Germany
 * 
 * Licensed under the Apache License, Version 2.0 (the "License");
 * you may not use this file except in compliance with the License.
 * You may obtain a copy of the License at
 *
 *      http://www.apache.org/licenses/LICENSE-2.0
 *
 * Unless required by applicable law or agreed to in writing, software
 * distributed under the License is distributed on an "AS IS" BASIS,
 * WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND, either express or implied.
 * See the License for the specific language governing permissions and
 * limitations under the License.
 */

package core.sync;

import core.Event;

/**
 * Interface for SimControllers used in parallel/distributed simulations. Used
 * to hide them towards the LPs.
 * 
 * @author Patrick Peschlow
 * 
 * @version 1.0
 */
public interface LpBasedSimController {
	/**
	 * Delivers an event from one LP to another.
	 * 
	 * @param event
	 *            the event.
	 * @param srcLpId
	 *            the ID of the sending LP.
	 */
	void sendEvent(Event event, int srcLpId);

	/**
	 * Provides the current safe time bound, calculated at the last barrier.
	 * 
	 * @return the current safe time bound.
	 */
	long getSafeTimeBound();
}
