/*
 * HiPWiNS - High Performance Wireless Network Simulator
 * File: core/sync/SinglePartitionBarrier.java
 * 
 * Copyright 2010 Institute of Computer Science 4, University of Bonn, Germany
 * 
 * Licensed under the Apache License, Version 2.0 (the "License");
 * you may not use this file except in compliance with the License.
 * You may obtain a copy of the License at
 *
 *      http://www.apache.org/licenses/LICENSE-2.0
 *
 * Unless required by applicable law or agreed to in writing, software
 * distributed under the License is distributed on an "AS IS" BASIS,
 * WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND, either express or implied.
 * See the License for the specific language governing permissions and
 * limitations under the License.
 */

package core.sync;

import edu.bonn.cs.net.jbarrier.barrier.Barrier;

/**
 * Dummy barrier to be used in parallel simulations with only a single
 * partition, e.g., for testing purposes.
 * 
 * @author Patrick Peschlow
 * 
 * @version 1.0
 */
public class SinglePartitionBarrier implements Barrier {
	/**
	 * The command to execute when the barrier is tripped, or <code>null</code>
	 * if there is no action.
	 */
	protected final Runnable action_;

	/**
	 * Constructor.
	 * 
	 * @param barrierAction
	 *            the barrier action.
	 */
	public SinglePartitionBarrier(Runnable barrierAction) {
		action_ = barrierAction;
	}

	/**
	 * @see edu.bonn.cs.net.jbarrier.barrier.AbstractBarrier#await(int)
	 */
	@Override
	public void await(int threadId) {
		action_.run();
	}

}
