/*
 * HiPWiNS - High Performance Wireless Network Simulator
 * File: modules/wireless/lazy/LazyPartition.java
 * 
 * Copyright 2010 Institute of Computer Science 4, University of Bonn, Germany
 * 
 * Licensed under the Apache License, Version 2.0 (the "License");
 * you may not use this file except in compliance with the License.
 * You may obtain a copy of the License at
 *
 *      http://www.apache.org/licenses/LICENSE-2.0
 *
 * Unless required by applicable law or agreed to in writing, software
 * distributed under the License is distributed on an "AS IS" BASIS,
 * WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND, either express or implied.
 * See the License for the specific language governing permissions and
 * limitations under the License.
 */

package modules.wireless.lazy;

/**
 * Interface for partitions that support lazy MAC state update.
 * 
 * @author Patrick Peschlow
 * 
 * @version 1.0
 */
public interface LazyPartition {
	/**
	 * Activate a lazy node that wants to transmit something, if it's not
	 * already active. The node's MAC state is calculated by parsing the signal
	 * history.
	 * 
	 * @param now
	 *            current simulation time
	 * @param radio
	 *            radio that is to be activated
	 */
	public void activateTxNode(long now, LazyRadio radio);

	/**
	 * Deactivate a lazy node.
	 * 
	 * @param now
	 *            current simulation time
	 * @param radio
	 *            radio that is to be deactivated
	 */
	public void deactivateNode(long now, LazyRadio radio);

	/**
	 * Provides information about whether a radio is currently active.
	 * 
	 * @param radio
	 *            the radio of interest
	 * @return whether radio is currently active
	 */
	public boolean isActive(LazyRadio radio);
}
