/*
 * HiPWiNS - High Performance Wireless Network Simulator
 * File: modules/wireless/scenario/DummyModule.java
 * 
 * Copyright 2010 Institute of Computer Science 4, University of Bonn, Germany
 * 
 * Licensed under the Apache License, Version 2.0 (the "License");
 * you may not use this file except in compliance with the License.
 * You may obtain a copy of the License at
 *
 *      http://www.apache.org/licenses/LICENSE-2.0
 *
 * Unless required by applicable law or agreed to in writing, software
 * distributed under the License is distributed on an "AS IS" BASIS,
 * WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND, either express or implied.
 * See the License for the specific language governing permissions and
 * limitations under the License.
 */

package modules.wireless.scenario;

import core.BaseModule;
import core.ModuleRoot;

/**
 * Dummy module class used for setting up distributed simulations.
 * 
 * @author Patrick Peschlow
 * @author Daniel Heupel
 */
public class DummyModule extends BaseModule {
	/**
	 * Dummy module to register to ModuleRoot, in order not to screw up module
	 * IDs.
	 */
	private static DummyModule dummyModule;

	/**
	 * Register the singleton dummy module to ModuleRoot.
	 * 
	 * @return the assigned module ID.
	 */
	public static int registerDummyModule() {
		if (dummyModule == null) {
			// Includes registration.
			dummyModule = new DummyModule(-1);
			return dummyModule.getId();
		} else {
			return ModuleRoot.getRoot().registerModule(dummyModule, -1);
		}
	}

	/**
	 * Constructor. Only call once!
	 * 
	 * @param number
	 *            dummy number.
	 */
	private DummyModule(int number) {
		super(number);
	}

	/**
	 * @see core.BaseModule#init()
	 */
	@Override
	public void init() {
		// Empty.
	}

	/**
	 * @see core.BaseModule#activate(long, int, java.lang.Enum,
	 *      java.lang.Object)
	 */
	@SuppressWarnings("rawtypes")
	@Override
	public void activate(long execTime, int srcModuleId, Enum eventId,
			Object parameter) {
		assert false;
	}

}
