package modules.wireless.scenario;

import core.Config;
import jist.swans.Constants;
import modules.wireless.scenario.NodeConfig;

// Trace file:
//Config.setTracefile("out.tr");

// Random seed:
Config.setRandomSeed(9876);
Config.setRandom(Config.Random.RNGSTREAM);

// Node configuration:
NodeConfig.setScenarioType(NodeConfig.ScenarioType.MESH);
NodeConfig.setRoutingProtocol(NodeConfig.RoutingProtocol.NONE);
NodeConfig.setNumAPs(9);
NodeConfig.setNumPortals(3);
NodeConfig.setTransmitPower_dBm(15.0);

// Traffic flows:
int numFlows = 20;
long maxStartTime = 1 * jist.swans.Constants.SECOND;
int packetSize = 1024;
long sendInterval = 1000 * jist.swans.Constants.MILLI_SECOND;
NodeConfig.addTrafficUDP(
	new NodeConfig.MeshTrafficInfoUDP(
		NodeConfig.FlowType.CLIENT_TO_CLIENT,
		NodeConfig.FlowDirection.SINGLE,
		numFlows,
		maxStartTime,
		sendInterval,
		packetSize
	)
);
NodeConfig.addTrafficUDP(
	new NodeConfig.MeshTrafficInfoUDP(
		NodeConfig.FlowType.CLIENT_TO_PORTAL,
		NodeConfig.FlowDirection.SINGLE,
		NodeConfig.FlowPriority.AC_VO,
		numFlows,
		maxStartTime,
		sendInterval,
		packetSize
	)
);
NodeConfig.addTrafficUDP(
	new NodeConfig.MeshTrafficInfoUDP(
		NodeConfig.FlowType.PORTAL_TO_CLIENT,
		NodeConfig.FlowDirection.SINGLE,
		NodeConfig.FlowPriority.AC_VO,
		numFlows,
		maxStartTime,
		sendInterval,
		packetSize
	)
);

// General simulation configuration:
Config.setSimType(Config.SimType.DISTRIBUTED, 4, 4);
Config.setEndTime(10 * jist.swans.Constants.SECOND);
Config.setScheduler(Config.Scheduler.SHIFTEDHEAP);

// Propagation model configuration.
Config.setPropagation(Config.Propagation.INDIVIDUAL);
Config.setPathlossModel(Config.PathlossModel.TWORAY);
Config.setFadingModel(Config.FadingModel.RAYLEIGH);

// Parallel simulation configuration:
Config.setBarrier(Config.BarrierType.TOURNAMENT);
Config.setLookahead(Config.Lookahead.EVENT);

// Mobility:
Config.setMovementFile("modules/wireless/scenario/bonnmotion/staticMesh100.movements");
Config.setMovement(Config.Movement.CONTINUOUS);