/*
 * HiPWiNS - High Performance Wireless Network Simulator
 * File: rng/DefaultRandomManager.java
 * 
 * Copyright 2010 Institute of Computer Science 4, University of Bonn, Germany
 * 
 * Licensed under the Apache License, Version 2.0 (the "License");
 * you may not use this file except in compliance with the License.
 * You may obtain a copy of the License at
 *
 *      http://www.apache.org/licenses/LICENSE-2.0
 *
 * Unless required by applicable law or agreed to in writing, software
 * distributed under the License is distributed on an "AS IS" BASIS,
 * WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND, either express or implied.
 * See the License for the specific language governing permissions and
 * limitations under the License.
 */

package rng;

import extern.RngStream;

/**
 * Random number generator manager class that offers random number streams based
 * on the RngStream.java class.
 * 
 * @author Patrick Peschlow
 * 
 * @version 1.0
 */
public class DefaultRandomManager extends RandomManager {
	/**
	 * Construtor.
	 * 
	 * @param seed
	 *            the global package seed.
	 */
	public DefaultRandomManager(int seed) {
		long[] seeds = { seed, seed, seed, seed, seed, seed };
		RngStream.setPackageSeed(seeds);
	}

	/**
	 * @see rng.RandomManager#getUniform01Substream()
	 */
	public RandomStream getUniform01Substream() {
		return new DefaultRandomStreamUniform(new RngStream(), 0.0, 1.0);
	}

	/**
	 * @see rng.RandomManager#getUniformSubstream(double, double)
	 */
	public RandomStream getUniformSubstream(double lower, double upper) {
		return new DefaultRandomStreamUniform(new RngStream(), lower, upper);
	}

	/**
	 * @see rng.RandomManager#getUniformIntSubstream(int, int)
	 */
	public RandomStreamInt getUniformIntSubstream(int lower, int upper) {
		return new DefaultRandomStreamUniformInt(new RngStream(), lower, upper);
	}

	/**
	 * @see rng.RandomManager#getNormal01Substream()
	 */
	public RandomStream getNormal01Substream() {
		return new DefaultRandomStreamNormal(new RngStream(), 0.0, 1.0);
	}

	/**
	 * @see rng.RandomManager#getNormalSubstream(double, double)
	 */
	public RandomStream getNormalSubstream(double mean, double stddev) {
		return new DefaultRandomStreamNormal(new RngStream(), mean, stddev);
	}
}
