/*
 * HiPWiNS - High Performance Wireless Network Simulator
 * File: rng/DefaultRandomStreamUniform.java
 * 
 * Copyright 2010 Institute of Computer Science 4, University of Bonn, Germany
 * 
 * Licensed under the Apache License, Version 2.0 (the "License");
 * you may not use this file except in compliance with the License.
 * You may obtain a copy of the License at
 *
 *      http://www.apache.org/licenses/LICENSE-2.0
 *
 * Unless required by applicable law or agreed to in writing, software
 * distributed under the License is distributed on an "AS IS" BASIS,
 * WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND, either express or implied.
 * See the License for the specific language governing permissions and
 * limitations under the License.
 */

package rng;

import extern.RngStream;

/**
 * A uniform random number stream based on the RngStream.java class.
 * 
 * @author Patrick Peschlow
 * 
 * @version 1.0
 */
public class DefaultRandomStreamUniform implements RandomStream {
	/**
	 * The RngStream used to implement this random stream.
	 */
	final RngStream gen_;

	/**
	 * The lower bound of the distribution.
	 */
	final double lower_;

	/**
	 * The upper bound of the distribution.
	 */
	final double upper_;

	/**
	 * The difference between the upper and lower bound (helper variable).
	 */
	final double diff_;

	/**
	 * Constructor.
	 * 
	 * @param gen
	 *            the RNG used to implement this stream.
	 * @param lower
	 *            the lower bound of the distribution.
	 * @param upper
	 *            the upper bound of the distribution.
	 */
	DefaultRandomStreamUniform(RngStream gen, double lower, double upper) {
		gen_ = gen;
		lower_ = lower;
		upper_ = upper;
		assert upper_ > lower_;
		diff_ = upper_ - lower_;
	}

	/**
	 * @see rng.RandomStream#nextDouble()
	 */
	public double nextDouble() {
		final double rnd = gen_.randU01();
		if (rnd <= 0.0) {
			return lower_;
		}
		if (rnd >= 1.0) {
			return upper_;
		}
		return lower_ + rnd * diff_;
	}
}
